@@ -1,4 +1,4 @@
-from .handlers import LokiQueueHandler, LokiHandler
+from .handlers import LokiThreadHandler, LokiAsyncioHandler, LokiHandler
 from .formatters import LokiLogFormatter
 from .emitters import LOKI_DEPLOY_STRATEGIES, \
     LOKI_DEPLOY_STRATEGY_ALL, LOKI_DEPLOY_STRATEGY_RANDOM, \
